#ifndef SEARCH_FILE_PATH_H
#define SEARCH_FILE_PATH_H

/*!
  \file
  \brief t@C̃pXT

  \author Satofumi KAMIMURA

  $Id$
*/

#include <string>
#include <vector>


namespace beego {
  /*!
    \brief pX̃t@C̒T

    \param full_path [o] Tʂ̃tpX
    \param fname [i] t@C
    \param dir_path [i] pX̔z

    \retval true t@CTɐAfull_path ɒTʂ̃tpXi[
    \retval false t@CTɎs

    gp
    \code
// ./beegoconf ܂ ~/.beego/beegoconf ̒T
std::vector<std::string> search_path;
search_path.push_back("./");
search_path.push_back("~/.beego/");

std::string config_file;
if (searchFilePath(config_file, "beegoconf", search_path)) {
   ...
}
    \endcode
  */
  extern bool searchFilePath(std::string& full_path, const char* fname,
			     const std::vector<std::string>& dir_path);
};

#endif /* SEARCH_FILE_PATH_H */
